yakumo.neutron.v2.vpn.ipsec_policy.Resource

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module ipsec_policy :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for VPN IPSec policies in Networking V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, auth_algorithm=`'``__UNDEF__``'`, encryption_algorithm=`'``__UNDEF__``'`, pfs=`'``__UNDEF__``'`, lifetime=`'``__UNDEF__``'`, encapsulation_mode=`'``__UNDEF__``'`, transform_protocol=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) Update properties of an IPSec policy | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, auth_algorithm=`'``__UNDEF__``'`, encryption_algorithm=`'``__UNDEF__``'`, pfs=`'``__UNDEF__``'`, lifetime=`'``__UNDEF__``'`, encapsulation_mode=`'``__UNDEF__``'`, transform_protocol=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) | source code
Update properties of an IPSec policy Parameters: `name` (str) - IPSec policy name `description` (str) - Description `auth_algorithm` (str) - Auth algorithm; only 'sha1' `encryption_algorithm` (str) - Encryption algorithm ('3des', 'aes-128', 'aes-192', ...) `pfs` (str) - Perfect forward secrecy ('Group2', 'Group5', 'Group14', ...) `encapsulation_mode` (str) - Encapsulation mode 'tunnel' or 'transport' `lifetime` (str) - Life time; e.q.'3600seconds' `transform_protocol` (str) - Transform protocol 'ESP', 'AH', or 'AH-ESP' `project` (yakumo.project.Resource) - Project object Returns: None Overrides: base.Resource.update